searchNodes=[{"doc":"Library for generating OHLC candles from trades. OHLC takes ordered list of trade events as input and outputs OHLC candles list. Library includes few options for appending candles to existing candles lists and more. This library could be useful if you want to create your own charting engine or trading bot. Documentation can be found here: https://hexdocs.pm/ohlc/1.0.0/OHLC.html Installation The package can be installed by adding ohlc to your list of dependencies in mix.exs : def deps do [ { :ohlc , &quot;~&gt; 1.1&quot; } ] end Example usage defmodule Example do def calculate_ohlc ( ) do trades = [ [ price : 12.21 , volume : 0.98 , time : 1616439921 ] , [ price : 12.54 , volume : 12.1 , time : 1616439931 ] , [ price : 12.56 , volume : 18.3 , time : 1616439952 ] , [ price : 18.9 , volume : 12 , time : 1616440004 ] , [ price : 11 , volume : 43.1 , time : 1616440025 ] , [ price : 18.322 , volume : 43.1 , time : 1616440028 ] ] case OHLC . create_candles ( trades , :minute ) do { :ok , data } -&gt; IO . inspect data { :error , msg } -&gt; IO . puts msg end end end Example output %{ candles : [ %{ close : 12.56 , etime : 1616439959 , high : 12.56 , low : 12.21 , open : 12.21 , processed : true , stime : 1616439900 , trades : 3 , type : :bullish , volume : 31.38 } , %{ close : 18.9 , etime : 1616440019 , high : 18.9 , low : 18.9 , open : 18.9 , processed : true , stime : 1616439960 , trades : 1 , type : :bearish , volume : 12.0 } , %{ close : 18.322 , etime : 1616440079 , high : 18.322 , low : 11.0 , open : 11.0 , processed : true , stime : 1616440020 , trades : 2 , type : :bullish , volume : 86.2 } ] , pair : nil , timeframe : :minute }","ref":"OHLC.html","title":"OHLC","type":"module"},{"doc":"Coverts candles to new timeframe. Parameters: candles - A list of candles. timeframe - Must be higher then the existing candles timeframe. For example if candles were previously created using :hour timeframe then the provided timeframe cannot be :minute. Returns a tuple containing the list of candles with converted timeframe.","ref":"OHLC.html#convert_timeframe/2","title":"OHLC.convert_timeframe/2","type":"function"},{"doc":"Function for generating candles from trades and timeframe provided. Parameters: trades - A list containing all the trades. Trades must be chronologically arranged(ASC) by the timestamp field. timeframe - Timeframe for the candles. opts - Option values for the data proccessing. Returns a tuple containing the metadata for the candles and a list of generated candles.","ref":"OHLC.html#create_candles/3","title":"OHLC.create_candles/3","type":"function"},{"doc":"Merges candle into another candle. If main candles :stime is 0 then fallback to the merge_child :stime . Parameters: main_candle - Candle which will be merged into. merge_candle - Candle which will be merged. It is important to have etime less than first candle. Meaning both candles should stay in the same timeframe.","ref":"OHLC.html#merge_child/2","title":"OHLC.merge_child/2","type":"function"},{"doc":"Single candle generated.","ref":"OHLC.html#t:candle/0","title":"OHLC.candle/0","type":"type"},{"doc":"A list of candles.","ref":"OHLC.html#t:candles/0","title":"OHLC.candles/0","type":"type"},{"doc":"Available options for create_candles/3 :forward_fill - When set true copies the previous candles closing price to the next candle if no trades happend to be in between. Useful when you don't want to get empty time gap between the generated candles. :validate_trades - When set true all trades are being validated before generating the candles to avoid errors and misinformation. :previous_candle - Trades are appended to the previous candle if possible before generating the new candles. :pair - Adds the pair name to the returned outputs metadata.","ref":"OHLC.html#t:opts/0","title":"OHLC.opts/0","type":"type"},{"doc":"Available timeframes for create_candles/3","ref":"OHLC.html#t:timeframe/0","title":"OHLC.timeframe/0","type":"type"},{"doc":"Single trade.","ref":"OHLC.html#t:trade/0","title":"OHLC.trade/0","type":"type"},{"doc":"A list of trades.","ref":"OHLC.html#t:trades/0","title":"OHLC.trades/0","type":"type"},{"doc":"OHLC Helper module containing all the helper functions.","ref":"OHLCHelper.html","title":"OHLCHelper","type":"module"},{"doc":"Helper function for formatting the value to float.","ref":"OHLCHelper.html#format_to_float/1","title":"OHLCHelper.format_to_float/1","type":"function"},{"doc":"Generates trades from provided arguments. Parameters: timeframe - Timeframe used for rounding the timestamp. Available values are: :minute , :hour , :day , :week min_price - The minimum price on the generated trades max_price - The maximum price on the generated trades volume - The volume each trade has volume - The volume each trade has volume - The volume each trade has timeframe_multiplier - If you'd like to generate less trades per candle then you can increase the size of the timeframe_divider parameter(1-100) otherwise leave empty. timeframe_divider - Is used for generating multiple candles of the same timeframe.","ref":"OHLCHelper.html#gen_trades/6","title":"OHLCHelper.gen_trades/6","type":"function"},{"doc":"Generates and returns empty candle. If provided with timeframe stime and etime will be generated based on current time.","ref":"OHLCHelper.html#generate_empty_candle/1","title":"OHLCHelper.generate_empty_candle/1","type":"function"},{"doc":"Gets the current candle type(pullish or bearish). Returns :bullish - if close price &gt; open price. bearish - if previous close price &lt;= open price.","ref":"OHLCHelper.html#get_candle_type/2","title":"OHLCHelper.get_candle_type/2","type":"function"},{"doc":"Gets the rounded timestamp based on the timeframe. Parameters: timestamp - Unix timestamp which will be rounded. timeframe - Timeframe used for rounding the timestamp. Available values are: :minute , :hour , :day , :week opts - Options for rounding the timestamp. Available values are: {:format, :stamp | :struct} - Returned value will be unix timestamp or DateTime struct. {:type, :down | :up | :jump} - Timestamp will be rounded up, down or jump to the next time cycle. Default is :up .","ref":"OHLCHelper.html#get_time_rounded/3","title":"OHLCHelper.get_time_rounded/3","type":"function"},{"doc":"Returns all available timeframes in seconds.","ref":"OHLCHelper.html#get_timeframes/0","title":"OHLCHelper.get_timeframes/0","type":"function"},{"doc":"Calculates the total volume from trades.","ref":"OHLCHelper.html#trades_total_volume/1","title":"OHLCHelper.trades_total_volume/1","type":"function"},{"doc":"Validates the data used for generating the OHLC candles. Accepts lists of candles, trades or both.","ref":"OHLCHelper.html#validate_data/2","title":"OHLCHelper.validate_data/2","type":"function"}]